@@ -1,26 +1,34 @@
 /* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
- * This package is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 dated June, 1991.
+ * This file is part of pdfdjvu.
+ *
+ * pdf2djvu is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * pdf2djvu is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  */
 
+#include "config.hh"
+
 #include <cerrno>
 #include <climits>
 #include <cstdlib>
 #include <limits>
+#include <sstream>
 #include <stdexcept>
 
 #include <getopt.h>
 
 #include "autoconf.hh"
-
-#include "config.hh"
-
 #include "debug.hh"
 #include "djvu-const.hh"
 #include "i18n.hh"
+#include "system.hh"
 
 class OptionsParseError : public Config::Error
 {
@@ -114,6 +122,14 @@ public:
   { }
 };
 
+class PageTitleEncodingError : public Config::Error
+{
+public:
+  explicit PageTitleEncodingError(const std::runtime_error &exc)
+  : Config::Error(string_printf(_("Unable to convert page title to UTF-8: %s"), exc.what()))
+  { }
+};
+
 class PageTitleTemplateParseError : public Config::Error
 {
 public:
@@ -628,7 +644,15 @@ void Config::read_config(int argc, char * const argv[])
     case OPT_PAGE_TITLE_TEMPLATE:
       try
       {
-        this->page_title_template.reset(new string_format::Template(optarg));
+        std::ostringstream sstream;
+        sstream << encoding::proxy<encoding::native, encoding::utf8>(optarg);
+        this->page_title_template.reset(
+          new string_format::Template(sstream.str())
+        );
+      }
+      catch (encoding::Error &exc)
+      {
+        throw PageTitleEncodingError(exc);
       }
       catch (string_format::ParseError)
       {
