@@ -1,30 +1,46 @@
 /* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
- * This package is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 dated June, 1991.
+ * This file is part of pdfdjvu.
+ *
+ * pdf2djvu is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * pdf2djvu is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  */
 
+#include "pdf-backend.hh"
+
 #include <algorithm>
 #include <cmath>
+#include <cstdarg>
+#include <cstring>
 #include <ctime>
 #include <iomanip>
-#include <iostream>
 #include <limits.h>
 #include <memory>
 #include <ostream>
 #include <sstream>
 #include <string>
 
+#include <Error.h>
+#include <GfxState.h>
+#include <GlobalParams.h>
+#include <PDFDoc.h>
+#include <goo/GooString.h>
+#include <goo/gtypes.h>
+#include <splash/SplashClip.h>
+#include <splash/SplashTypes.h>
+
 #include "debug.hh"
 #include "i18n.hh"
-#include "pdf-backend.hh"
 #include "pdf-unicode.hh"
 #include "system.hh"
 
-#include <Error.h>
-#include <GlobalParams.h>
 
 /* class pdf::Environment
  * ======================
