@@ -1,14 +1,21 @@
 /* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
- * This package is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 dated June, 1991.
+ * This file is part of pdfdjvu.
+ *
+ * pdf2djvu is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * pdf2djvu is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  */
 
 #include <algorithm>
 #include <cassert>
-#include <cmath>
+#include <cstdlib>
 #include <iomanip>
 #include <iostream>
 #include <limits>
@@ -16,12 +23,16 @@
 #include <memory>
 #include <set>
 #include <sstream>
+#include <stdexcept>
+#include <string>
+#include <utility>
 #include <vector>
+
 #if _OPENMP
 #include <omp.h>
 #endif
 
-#include "autoconf.hh"
+#include <stdint.h>
 
 #include "config.hh"
 #include "debug.hh"
@@ -34,9 +45,10 @@
 #include "pdf-dpi.hh"
 #include "pdf-unicode.hh"
 #include "sexpr.hh"
+#include "string-format.hh"
 #include "system.hh"
-#include "xmp.hh"
 #include "version.hh"
+#include "xmp.hh"
 
 Config config;
 
@@ -1077,8 +1089,9 @@ void IndirectDjVm::create(const std::vector<Component> &components, bool bare)
     {
       bzz_file << it->get_basename() << '\0';
       const std::string *title = it->get_title();
-      if (title != NULL)
-        bzz_file << encoding::proxy<encoding::native, encoding::utf8>(*title) << '\0';
+      if (title == NULL)
+        continue;
+      bzz_file << *title << '\0';
     }
     bzz_file.close();
     DjVuCommand bzz("bzz");
@@ -1089,10 +1102,11 @@ void IndirectDjVm::create(const std::vector<Component> &components, bool bare)
   this->index_file.seekg(20, std::ios::beg);
   for (int i = 3; i >= 0; i--)
     this->index_file << static_cast<char>(((dirm_off - 24) >> (8 * i)) & 0xff);
+  dirm_off += dirm_off & 1;
   if (!bare && this->outline_stream.get())
   {
     TemporaryFile bzz_file;
-    this->index_file.seekg(0, std::ios::end);
+    this->index_file.seekg(dirm_off, std::ios::beg);
     index_file.write("NAVM\0\0\0", 8);
     bzz_file << this->outline_stream->str();
     bzz_file.close();
@@ -1615,7 +1629,7 @@ static int xmain(int argc, char * const argv[])
    */
   catch (std::ios_base::failure &ex)
   {
-    error_log << string_printf(_("I/O error (%s)"), ex.what()) << std::endl;
+    error_log << string_printf(_("Input/output error (%s)"), ex.what()) << std::endl;
     exit(2);
   }
   catch (std::runtime_error &ex)
@@ -1717,7 +1731,7 @@ try
 /* Please keep the exception handlers in sync with the ones in xmain(). */
 catch (std::ios_base::failure &ex)
 {
-  error_log << string_printf(_("I/O error (%s)"), ex.what()) << std::endl;
+  error_log << string_printf(_("Input/output error (%s)"), ex.what()) << std::endl;
   exit(2);
 }
 catch (std::runtime_error &ex)
