@@ -1,20 +1,26 @@
-/* Copyright © 2009-2013 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
- * This package is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 dated June, 1991.
+ * pdf2djvu is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * pdf2djvu is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  */
 
+#include "string-format.hh"
+
+#include <climits>
 #include <iomanip>
-#include <iostream>
-#include <limits>
+#include <ostream>
 #include <sstream>
 #include <stdexcept>
 #include <string>
 #include <vector>
 
-#include "string-format.hh"
 #include "i18n.hh"
 
 #if __cplusplus < 201103
@@ -45,7 +51,7 @@ namespace string_format
   protected:
     std::string variable;
     bool negative_offset;
-    uint_tp offset;
+    unsigned int offset;
     unsigned int width;
     bool auto_width;
     bool pad_0;
@@ -108,7 +114,7 @@ string_format::VariableChunk::VariableChunk(const std::string &description)
     case OFFSET_2:
       if (*it >= '0' && *it <= '9')
       {
-        if (this->offset > (std::numeric_limits<uint_tp>::max() - 9) / 10)
+        if (this->offset > (UINT_MAX - 9) / 10)
           throw IntegerOverflow();
         this->offset = this->offset * 10 + (*it - '0');
       }
@@ -129,7 +135,7 @@ string_format::VariableChunk::VariableChunk(const std::string &description)
     case WIDTH_2:
       if (*it >= '0' && *it <= '9')
       {
-        if (this->width > (std::numeric_limits<decltype(this->width)>::max() - 9) / 10)
+        if (this->width > (UINT_MAX - 9) / 10)
           throw IntegerOverflow();
         this->width = this->width * 10 + (*it - '0');
       }
@@ -151,7 +157,7 @@ string_format::VariableChunk::VariableChunk(const std::string &description)
     this->variable = description;
 }
 
-static string_format::uint_tp shift(string_format::uint_tp value, string_format::uint_tp offset, bool negative_offset)
+static unsigned int shift(unsigned int value, unsigned int offset, bool negative_offset)
 {
   if (negative_offset)
   {
@@ -169,11 +175,11 @@ static string_format::uint_tp shift(string_format::uint_tp value, string_format:
 
 void string_format::VariableChunk::format(const Bindings &bindings, std::ostream &stream) const
 {
-  uint_tp value = shift(bindings.get(this->variable), this->offset, this->negative_offset);
+  unsigned int value = shift(bindings.get(this->variable), this->offset, this->negative_offset);
   unsigned int width = this->width;
-  if (auto_width)
+  if (this->auto_width)
   {
-    uint_tp max_value = shift(bindings.get("max_" + this->variable), this->offset, this->negative_offset);
+    unsigned int max_value = shift(bindings.get("max_" + this->variable), this->offset, this->negative_offset);
     unsigned int max_digits = 0;
     while (max_value > 0)
     {
