@@ -2,22 +2,27 @@
 
 # Copyright © 2015 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of pdfdjvu.
+#
+# pdf2djvu is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation.
+#
+# pdf2djvu is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# General Public License for more details.
 
-import tempfile
-
-from common import (
+from tools import (
     assert_equal,
     case,
     re,
 )
 
 class test(case):
-    '''
-    fixed in [e98f3c4cfa2e]
-    '''
+    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/98
+    # + fixed in 0.8 [e98f3c4cfa2e]
+
     def test_overwrite(self):
         pdf_path = self.get_pdf_path()
         with open(pdf_path, 'rb') as pdf_file:
