@@ -2,12 +2,19 @@
 
 # Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
 #
-# This package is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 dated June, 1991.
+# This file is part of pdfdjvu.
+#
+# pdf2djvu is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation.
+#
+# pdf2djvu is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# General Public License for more details.
 
-from common import (
-    assert_grep,
+from tools import (
+    assert_regex,
     case,
 )
 
@@ -15,7 +22,7 @@ class test(case):
     def test_verbatim(self):
         self.pdf2djvu('--verbatim-metadata').assert_()
         xmp = self.extract_xmp()
-        assert_grep(xmp, '<broken')
+        assert_regex(xmp, '<broken')
 
     def test_no_verbatim(self):
         self.require_feature('GNOME XSLT')
@@ -32,6 +39,6 @@ Entity: line 1: parser error : Couldn't find end of Start Tag broken line 1
                                              ^
 ''')
         xmp = self.extract_xmp()
-        assert_grep(xmp, '<broken')
+        assert_regex(xmp, '<broken')
 
 # vim:ts=4 sts=4 sw=4 et
