@@ -1,19 +1,29 @@
 /* Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
  *
- * This package is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 dated June, 1991.
+ * This file is part of pdfdjvu.
+ *
+ * pdf2djvu is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * pdf2djvu is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  */
 
+#include "xmp.hh"
+
 #include "i18n.hh"
 #include "autoconf.hh"
 #include "version.hh"
-#include "xmp.hh"
 
 #if HAVE_LIBXSLT
 
-#include <sstream>
+#include <cstddef>
 #include <memory>
+#include <sstream>
+#include <vector>
 
 #include <libxml/xmlIO.h>
 #include <libxml/xmlmemory.h>
